@@ -8,6 +8,7 @@ from tempfile import TemporaryDirectory
 import cloudpickle
 import numpy as np
 import pandas as pd
+from sklearn.base import TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
 import goldilox
@@ -18,7 +19,7 @@ from goldilox.utils import _is_s3_url
 logger = logging.getLogger()
 
 
-class Pipeline:
+class Pipeline(TransformerMixin):
     pipeline_type: str
     description: str
     BYTES_SIGNETURE = b"Goldilox"
@@ -225,11 +226,14 @@ class Pipeline:
             X = df if df is not None else self.infer(self.raw)
             if verbose:
                 logger.info("validate inference")
-            assert len(pipeline.inference(X)) == len(X)
+            try:
+                assert len(pipeline.inference(X)) == len(X)
+            except AssertionError as e:
+                logger.error("WARNING: Pipeline filter data on inference")
             if check_na:
                 pipeline._validate_na()
         elif verbose:
-            logger.warning("No data provided for inference validation - skip")
+            logger.warning("WARNING: No data provided for inference validation - skip")
         return True
 
     def _validate_na(self):
@@ -240,10 +244,10 @@ class Pipeline:
             tmp[column] = None
             try:
                 with np.errstate(all='ignore'):
-                    self.inference(tmp).to_records()
+                    Pipeline.to_raw(self.inference(tmp))
             except Exception as e:
                 ret = False
-                logger.warning(f"Pipeline doesn't handle NA for {column}")
+                logger.warning(f"WARNING: Pipeline doesn't handle NA for {column}")
         return ret
 
     def fit(self, df, **kwargs):
